InitIglmTerm: Initialize iglm Model Terms

View source: R/init_terms.R

InitIglmTermR Documentation

Initialize iglm Model Terms

Description

This is an internal generic function used to initialize mapping and data for terms in a iglm.object formula.

Usage

InitIglmTerm(data_object, arglist, ...)

Arguments

data_object

An iglm.data object.

arglist

A list of arguments passed to the term in the formula.

...

Additional arguments.

Value

A list containing information for the C++ backend.


iglm documentation built on April 23, 2026, 5:07 p.m.