| InitIglmTerm | R Documentation |
This is an internal generic function used to initialize mapping and data
for terms in a iglm.object formula.
InitIglmTerm(data_object, arglist, ...)
data_object |
An |
arglist |
A list of arguments passed to the term in the formula. |
... |
Additional arguments. |
A list containing information for the C++ backend.
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.