| copenhagen | R Documentation |
A preprocessed dataset containing social ties, physical proximity, and nodal
attributes for a subset of participants in the Copenhagen Networks Study.
The object is provided as an iglm.data class.
data(copenhagen)
The iglm.data provides the following information:
A E \times 2 integer matrix representing the
undirected friendship network ($Z$).
A logical/binomial vector of length N indicating
gender (1 for female, 0 for male).
A numeric vector of length N representing the
log-transformed total call duration in minutes:
y_i = \log(\frac{\text{seconds}}{60}).
A matrix defining the proximity-based constraint space. Pairs are included if their cumulative physical proximity exceeded 24 hours during the observation period.
Boolean TRUE, indicating that the x attribute
is treated as exogenous.
The following preprocessing steps were carried out:
Temporal Aggregation: Proximity data (Bluetooth scans) were aggregated into sessions. A session break was defined by any temporal gap exceeding 10 minutes.
Recursive Pruning: A recursive filter removed actors with missing
gender information or isolated actors in either the
friendship (z_network) or proximity (neighborhood) networks,
Sapiezynski, P., Stopczynski, A., Lassen, D. D. and Lehmann, S. (2019), Interaction data from the Copenhagen Networks Study. Scientific Data 6(1), 315.
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.