| statistics | R Documentation |
Computes statistics.
statistics(formula)
formula |
A model 'formula' object. The left-hand side should be the
name of a |
A named numeric vector. Each element corresponds to a term in the
'formula', and its value is the calculated observed feature
for that term based on the data in the iglm.data object. The names of the
vector match the coefficient names derived from the formula terms.
# Create a iglm.data object
n_actor <- 10
neighborhood <- matrix(1, nrow = n_actor, ncol = n_actor)
type_x <- "binomial"
type_y <- "binomial"
x_attr_data <- rbinom(n_actor, 1, 0.5)
y_attr_data <- rbinom(n_actor, 1, 0.5)
z_net_data <- matrix(0, nrow = n_actor, ncol = n_actor)
object <- iglm.data(
z_network = z_net_data, x_attribute = x_attr_data,
y_attribute = y_attr_data, neighborhood = neighborhood,
directed = FALSE, type_x = type_x, type_y = type_y
)
statistics(object ~ edges(mode = "local") + attribute_y + attribute_x)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.